import 'package:flutter/material.dart';

import 'package:kitcod_uikit_flutter/kitcod_uikit_flutter.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Kidcod UIKit Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Kidcod UIKit Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  TextButton _profileOverview() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => UserProfileView(
                headerView: HeaderView(
                  backgroundColor: Colors.indigoAccent.withOpacity(0.1),
                  leftSideIcon: IconButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    icon: const Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black,
                    ),
                  ),
                  header: const Text(
                    "Profile Overview",
                    style: TextStyle(color: Colors.black),
                  ),
                  headerAlignment: Alignment.centerLeft,
                ),
                name: const Text(
                  "Bilal",
                  style: TextStyle(
                    fontSize: 20.0,
                    fontWeight: FontWeight.bold,
                  ),
                ),
                city: const Text(
                  "Islamabad",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                email: const Text(
                  "bilal.shahid@kitcod.com",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                about: const Text(
                  "Flutter Developer",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                button: Button(
                  name: "Follow",
                  onPressed: () {},
                  backgroundColor: Colors.indigoAccent,
                  textStyle: const TextStyle(color: Colors.white),
                ),
              ),
            ),
          );
        },
        child: const Center(child: Text("UserProfileView Screen")),
      );

  TextButton _createPost() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => CreatePost(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                    header: const Text(
                      "Create New",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                  ),
                  name: "Bilal Shahid",
                  userName: "@bilal_sh",
                  porfileImageUrl: "https://picsum.photos/201",
                  groupTags: const [
                    "#Brothers of mirzapur",
                    "#Wishes and friends"
                  ],
                  groupsList: feedGroupsArraySimple,
                  postType: const [PostType.announcement, PostType.poll],
                  moreOptions: const [
                    MoreOptions.image,
                    MoreOptions.video,
                    MoreOptions.audio
                  ]),
            ),
          );
        },
        child: const Center(child: Text("CreatePost Screen")),
      );

  TextButton _createGroup() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroup(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Create New Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Screen")));

  TextButton _createGroupCommunity() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroupCommunity(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Create New Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Community Screen")));

  TextButton _createGroupSetting() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroupSetting(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Finish Setting Up Your Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Setting Screen")));

  TextButton _newsFeed() => TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => NewsFeed(
                        headerView: HeaderView(
                          backgroundColor: Colors.white.withOpacity(0.1),
                          header: const Text(
                            "News Feed",
                            style: TextStyle(color: Colors.black),
                          ),
                          headerAlignment: Alignment.centerLeft,
                        ),
                        feedGroupsArray: feedGroupsArray,
                        feedPostsArray: feedPostsArray,
                        name: "Bilal Shahid",
                        userName: "@bilal_sh",
                        profileImageUrl: "https://picsum.photos/201",
                        groupTags: const [
                          "#Brothers of mirzapur",
                          "#Wishes and friends"
                        ],
                        groupList: feedGroupsArraySimple,
                      )));
        },
        child: const Center(child: Text("News Feed Screen")),
      );

  TextButton _myGroups() => TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => MyGroups(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    header: const Text(
                      "My groups",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                  ),
                  groupsList: feedGroupsArray,
                ),
              ));
        },
        child: const Center(child: Text("My groups")),
      );

  TextButton _groups() => TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => Groups(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    header: const Text(
                      "Groups",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                  ),
                  groupsList: feedGroupsArray,
                ),
              ));
        },
        child: const Center(child: Text("Groups")),
      );

  @override
  Widget build(BuildContext context) => Scaffold(
        body: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            _profileOverview(),
            _createPost(),
            _newsFeed(),
            _createGroup(),
            _createGroupCommunity(),
            _createGroupSetting(),
            _myGroups(),
            _groups()
          ],
        ),
      );
}

List<FeedGroup> feedGroupsArraySimple = [
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/200",
    groupTitle: "#Brothers of Mirzapur",
    members: "12k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/201",
    groupTitle: "#People of Wisdom",
    members: "321k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/202",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
];

List<FeedGroup> feedGroupsArray = [
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Brothers of Mirzapur",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      isJoined: true,
      groupStatus: "Open group",
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
        FeedPost(
            profileImageUrl: "https://picsum.photos/202",
            groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
            name: "Harry Potter",
            username: "@hp_90",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
            postedTime: "10m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            feedVideoUrl:
                "https://flutter.github.io/assets-for-api-docs/assets/videos/butterfly.mp4",
            feedWebsiteUrl: "www.google.com",
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Brothers of Mirzapur",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Brothers of Mirzapur",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: [
              "#Brothers of mirzapur",
              "#Wishes and friends",
            ],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
];

List<FeedPost> feedPostsArray = [
  const FeedPost(
      feedImageUrl: "https://picsum.photos/200",
      profileImageUrl: "https://picsum.photos/201",
      groupTags: [
        "#Brothers of mirzapur",
        "#Wishes and friends",
      ],
      name: "Bilal Shahid",
      username: "@bilal_sh",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
      postedTime: "2m ago",
      likes: 90,
      comments: 80,
      shares: 66,
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        ),
        Comment(
          profileImageUrl: "https://picsum.photos/202",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Hsrdik Pandya",
          username: "@hhd007",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/202",
      groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
      name: "Harry Potter",
      username: "@hp_90",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "10m ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedVideoUrl:
          "https://flutter.github.io/assets-for-api-docs/assets/videos/butterfly.mp4",
      feedWebsiteUrl: "www.google.com",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      feedImageUrl: "https://picsum.photos/202",
      profileImageUrl: "https://picsum.photos/203",
      groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
      name: "Michael Scott",
      username: "@michael99",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
      name: "James Dean",
      username: "@jdean",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedPollDetails: PollDetails(
        creator: "admin",
        currentUser: "bilalshah",
        usersWhoVoted: {
          "test@gmail.com": 1,
          "deny@gmail.com": 3,
          "kent@gmail.com": 2,
          "xyz@gmail.com": 3
        },
        pollTitle: "What creator economy means to you?",
        pollOptions: {
          "Making more money": 1,
          "Bussiness interactions increasing": 3,
          "Showcasing brand value": 2,
        },
      ),
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shah",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
      name: "James Dean",
      username: "@jdean",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedWebsiteUrl: "www.google.com",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
      name: "James Dean",
      username: "@jdean",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedImageUrl: "https://picsum.photos/204",
      feedAudioTitle: "Beautiful Music - Eric Partaalu",
      feedAudioUrl:
          "https://www.soundhelix.com/examples/mp3/SoundHelix-Song-1.mp3",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Brothers of mirzapur", "#Wishes and friends"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
];
