part of kitcod_uikit_flutter;

class BottomSheet extends StatelessWidget {
  const BottomSheet({
    required this.optionsHeading,
    this.postType,
    this.moreOptions,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final Text optionsHeading;
  final List<PostType>? postType;
  final List<MoreOptions>? moreOptions;

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  TextButton build(final BuildContext context) => TextButton(
        onPressed: () => showModalBottomSheet(
            isScrollControlled: true,
            shape: const RoundedRectangleBorder(
                borderRadius: BorderRadius.vertical(
              top: Radius.circular(20),
            )),
            context: context,
            builder: (final context) => Container(
                padding: const EdgeInsets.all(8),
                child: Wrap(
                  children: [
                    Container(
                      alignment: Alignment.center,
                      child: SizedBox(
                        width: MediaQuery.of(context).size.width * 0.15,
                        height: 3,
                        child: DecoratedBox(
                          decoration:
                              BoxDecoration(color: Colors.indigo.shade100),
                        ),
                      ),
                    ),
                    Padding(
                        padding: const EdgeInsets.all(15),
                        child: optionsHeading),
                    if (postType != null)
                      for (var option in postType!)
                        if (option == PostType.announcement)
                          BottomSheetOption(
                              heading: "Announcement",
                              description:
                                  "Priority notifications to followers",
                              icon: const Icon(Icons.notifications),
                              iconBackgroundColor: Colors.indigo.shade50)
                        else if (option == PostType.poll)
                          BottomSheetOption(
                              heading: "Post",
                              description: "Standard Post",
                              icon: const Icon(Icons.post_add_rounded),
                              iconBackgroundColor: Colors.indigo.shade50)
                        else if (option == PostType.poll)
                          BottomSheetOption(
                              heading: "Poll",
                              description: "Get opinion from your followers",
                              icon: const Icon(Icons.poll),
                              iconBackgroundColor: Colors.indigo.shade50),
                    if (moreOptions != null)
                      for (var option in moreOptions!)
                        if (option == MoreOptions.image)
                          BottomSheetOption(
                              heading: "Image",
                              description: "Add multiple images to your post",
                              icon: const Icon(Icons.notifications),
                              iconBackgroundColor: Colors.indigo.shade50)
                        else if (option == MoreOptions.video)
                          BottomSheetOption(
                              heading: "Video",
                              description: "Add Video links to your post",
                              icon:
                                  const Icon(Icons.video_camera_back_outlined),
                              iconBackgroundColor: Colors.indigo.shade50)
                        else if (option == MoreOptions.audio)
                          BottomSheetOption(
                              heading: "Audio",
                              description: "Add Audio files to your post",
                              icon: const Icon(Icons.poll),
                              iconBackgroundColor: Colors.indigo.shade50)
                        else if (option == MoreOptions.button)
                          BottomSheetOption(
                              heading: "Button",
                              description:
                                  "Add a Button to your website or blog",
                              icon: const Icon(Icons.smart_button_outlined),
                              iconBackgroundColor: Colors.indigo.shade50),
                  ],
                ))),
        child: Container(
          decoration: BoxDecoration(
              border: Border.all(
                color: Colors.grey,
              ),
              borderRadius: const BorderRadius.all(Radius.circular(20))),
          margin: const EdgeInsets.symmetric(horizontal: 10),
          height: MediaQuery.of(context).size.height * 0.09,
          width: MediaQuery.of(context).size.width,
          child: Padding(
            padding: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                Row(children: [
                  if (postType != null)
                    BottomSheetOption(
                        heading: "Announcement",
                        description: "Priority notifications to followers",
                        icon: const Icon(Icons.notifications),
                        iconBackgroundColor: Colors.indigo.shade50),
                  if (moreOptions != null)
                    BottomSheetOption(
                        heading: "Image",
                        description: "Add multiple images to your post",
                        icon: const Icon(Icons.notifications),
                        iconBackgroundColor: Colors.indigo.shade50)
                ]),
                const Icon(
                  Icons.keyboard_arrow_down_sharp,
                  textDirection: TextDirection.rtl,
                  color: Colors.black,
                )
              ],
            ),
          ),
        ),
      );
}
