part of kitcod_uikit_flutter;

class FeedPostCard extends StatefulWidget {
  const FeedPostCard({
    required this.feedPost,
    required this.buildContext,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final FeedPost feedPost;
  final BuildContext buildContext;

  @override
  State<FeedPostCard> createState() => _FeedPostCardState();
}

class _FeedPostCardState extends State<FeedPostCard> {
  // -------------------------------- VARIABLES -------------------------------- //
  late AudioPlayer player;

  bool _isAudioStopped = true;
  bool _isAudioPlaying = false;

  // -------------------------------- LIFECYCLE FUNCTION -------------------------------- //

  @override
  void initState() {
    super.initState();
    player = AudioPlayer();

    player.onPlayerCompletion.listen((final _) {
      setState(() {
        _isAudioPlaying = false;
        _isAudioStopped = true;
      });
    });
  }

  @override
  void dispose() {
    player.dispose();
    super.dispose();
  }

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  SizedBox build(final context) => SizedBox(
        child: postCard(widget.feedPost, context),
      );

  // -------------------------------- UI FUNCTION -------------------------------- //

  Column postCard(final FeedPost feedPost, final BuildContext buildContext) =>
      Column(
        children: [
          Padding(
            padding: const EdgeInsets.only(bottom: 10),
            child: SizedBox(
              width: MediaQuery.of(buildContext).size.width,
              height: 3,
              child: DecoratedBox(
                decoration: BoxDecoration(color: Colors.indigo.shade50),
              ),
            ),
          ),
          ProfileDetails(
              name: feedPost.name,
              userName: feedPost.username,
              profileImageUrl: feedPost.profileImageUrl,
              groupTags: feedPost.groupTags),
          Padding(
            padding: const EdgeInsets.only(left: 50, right: 10),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(feedPost.postedTime,
                    style: const TextStyle(
                      fontSize: 15,
                      color: Colors.grey,
                    )),
                if (feedPost.description != null)
                  Padding(
                    padding: const EdgeInsets.only(top: 10),
                    child: Text(feedPost.description!,
                        style:
                            const TextStyle(fontSize: 15, color: Colors.black)),
                  ),
                if (feedPost.feedImageUrl != null)
                  Padding(
                    padding: const EdgeInsets.only(top: 10),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(5), // Image border
                      child: SizedBox.fromSize(
                        child: Image.network(
                          feedPost.feedImageUrl!,
                          fit: BoxFit.cover,
                          width: MediaQuery.of(buildContext).size.width * 0.75,
                          height: MediaQuery.of(buildContext).size.height * 0.2,
                        ),
                      ),
                    ),
                  ),
                if (feedPost.feedVideoUrl != null)
                  Padding(
                    padding: const EdgeInsets.only(right: 15, left: 15),
                    child: VideoWidget(
                      videoPlayerController: VideoPlayerController.network(
                        feedPost.feedVideoUrl!,
                      ),
                      looping: true,
                      autoplay: false,
                    ),
                  ),
                if (feedPost.feedWebsiteUrl != null)
                  Padding(
                    padding:
                        const EdgeInsets.only(top: 10, right: 15, left: 15),
                    child: Button(
                      name: "Visit Website",
                      onPressed: () {},
                      backgroundColor: Colors.indigo,
                      textStyle: const TextStyle(color: Colors.white),
                      height: MediaQuery.of(buildContext).size.height * 0.04,
                      width: MediaQuery.of(buildContext).size.width,
                    ),
                  ),
                if (feedPost.feedPollDetails != null)
                  PollsView(
                    pollTitle: feedPost.feedPollDetails!.pollTitle,
                    creator: feedPost.feedPollDetails!.creator,
                    currentUser: feedPost.feedPollDetails!.currentUser,
                    pollOptions: feedPost.feedPollDetails!.pollOptions,
                    usersWhoVoted: feedPost.feedPollDetails!.usersWhoVoted,
                  ),
                if (feedPost.feedAudioTitle != null)
                  Padding(
                    padding: const EdgeInsets.all(10),
                    child: Text(
                      feedPost.feedAudioTitle!,
                      style: const TextStyle(
                          fontSize: 17,
                          fontWeight: FontWeight.bold,
                          color: Colors.black),
                    ),
                  ),
                if (feedPost.feedAudioUrl != null)
                  TextButton(
                      onPressed: () {
                        setState(() {
                          if (_isAudioPlaying && !_isAudioStopped) {
                            player.pause();
                            _isAudioPlaying = false;
                          } else if (!_isAudioPlaying && !_isAudioStopped) {
                            player.resume();
                            _isAudioPlaying = true;
                          } else {
                            player.play(feedPost.feedAudioUrl!);
                            _isAudioStopped = false;
                            _isAudioPlaying = true;
                          }
                        });
                      },
                      style: ElevatedButton.styleFrom(
                          shape: const CircleBorder(),
                          padding: const EdgeInsets.all(24),
                          onPrimary: Colors.white,
                          primary: Colors.indigo),
                      child: Icon(_isAudioPlaying
                          ? Icons.pause
                          : Icons.play_arrow_sharp)),
                ShareStatsIcons(
                    likes: feedPost.likes,
                    comments: feedPost.comments,
                    shares: feedPost.shares)
              ],
            ),
          ),
          const SizedBox(height: 10),
        ],
      );
}
