part of kitcod_uikit_flutter;

class GroupPage extends StatelessWidget {
  const GroupPage({
    required this.groupImageUrl,
    required this.groupTitle,
    required this.members,
    required this.membersListUrl,
    required this.groupStatus,
    required this.groupAbout,
    required this.groupPosts,
    this.isJoined,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final String groupImageUrl;
  final String groupTitle;
  final String members;
  final List<String> membersListUrl;
  final String groupStatus;
  final String groupAbout;
  final List<FeedPost> groupPosts;
  final bool? isJoined;

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Scaffold build(final context) => Scaffold(
        backgroundColor: Colors.white,
        body: SingleChildScrollView(
          child: SafeArea(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Stack(children: <Widget>[
                  Image.network(
                    groupImageUrl,
                    width: MediaQuery.of(context).size.width,
                    height: MediaQuery.of(context).size.height * 0.3,
                    fit: BoxFit.cover,
                  ),
                  Positioned(
                      top: 10,
                      child: TextButton(
                          onPressed: () => {Navigator.pop(context)},
                          style: ElevatedButton.styleFrom(
                              shape: const CircleBorder(),
                              padding: const EdgeInsets.all(10),
                              onPrimary: Colors.black,
                              primary: Colors.white.withOpacity(0.7)),
                          child: const Icon(Icons.arrow_back_ios_new_sharp))),
                  Positioned(
                      right: 10,
                      top: 10,
                      child: TextButton(
                          onPressed: () => {},
                          style: ElevatedButton.styleFrom(
                              shape: const CircleBorder(),
                              padding: const EdgeInsets.all(10),
                              onPrimary: Colors.black,
                              primary: Colors.white.withOpacity(0.7)),
                          child: const Icon(Icons.menu_outlined))),
                ]),
                Padding(
                  padding: const EdgeInsets.only(left: 20, top: 20, right: 20),
                  child: Text(
                    groupTitle,
                    style: const TextStyle(
                      fontSize: 30,
                      fontWeight: FontWeight.bold,
                      color: Colors.black,
                    ),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.only(left: 20, top: 10),
                  child: RichText(
                    text: TextSpan(
                        text: groupStatus,
                        style:
                            const TextStyle(fontSize: 17, color: Colors.grey),
                        children: <TextSpan>[
                          TextSpan(
                            text: "   $members",
                            style: const TextStyle(
                                fontSize: 17,
                                fontWeight: FontWeight.bold,
                                color: Colors.black),
                          )
                        ]),
                  ),
                ),
                if (!isJoined!)
                  Padding(
                    padding:
                        const EdgeInsets.only(left: 20, top: 20, right: 20),
                    child: Button(
                      name: "Join",
                      onPressed: () {},
                      backgroundColor: Colors.indigo,
                      textStyle: const TextStyle(color: Colors.white),
                      height: MediaQuery.of(context).size.height * 0.04,
                      width: MediaQuery.of(context).size.width,
                    ),
                  ),
                if (isJoined!)
                  Padding(
                    padding:
                        const EdgeInsets.only(left: 20, top: 20, right: 20),
                    child: Row(
                      children: [
                        RowSuper(
                          innerDistance: -10,
                          children: [
                            for (String member in membersListUrl)
                              CircleAvatar(
                                radius: 15,
                                backgroundImage: NetworkImage(member),
                              ),
                          ],
                        ),
                        Padding(
                          padding: const EdgeInsets.all(10),
                          child: Button(
                            name: "Invite",
                            onPressed: () {},
                            backgroundColor: Colors.indigo,
                            textStyle: const TextStyle(color: Colors.white),
                            height: MediaQuery.of(context).size.height * 0.04,
                            width: MediaQuery.of(context).size.width * 0.2,
                          ),
                        ),
                      ],
                    ),
                  ),
                const Padding(
                  padding: EdgeInsets.only(left: 20, top: 20, right: 20),
                  child: Text(
                    "About",
                    style: TextStyle(
                      fontSize: 20,
                      fontWeight: FontWeight.bold,
                      color: Colors.black,
                    ),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.only(
                      left: 20, top: 10, right: 20, bottom: 20),
                  child: Text(groupAbout,
                      style: const TextStyle(fontSize: 15, color: Colors.grey)),
                ),
                FeedPostsList(
                  feedPostsArray: groupPosts,
                ),
              ],
            ),
          ),
        ),
      );
}
